#  FileName:  EnumSettings.ps1   
#*=============================================================================
#* Script Name:	[Enumerate Settings]
#* Last Modified:	[11/21/2008]
#* Author:		Chethana Das
#* Company:	Hewlett-Packard
#*=============================================================================
#* Purpose:	A Powershell example script to read BIOS setting
#*		information from the HP Client Management Interface.             
#*	Copyright (c) 2008-2009, Hewlett-Packard Development Company
#*=============================================================================
$Version=	"1.0.0.0"
$ScriptName = "EnumSettings.ps1"
$Copyright = "Copyright (c) 2008-2009, Hewlett-Packard Development Company"

# =============================================================================
#  FUNCTION LISTINGS
# =============================================================================
#  Function:    	EnumSetting 
#  Arguments:  	[string]$strSetting: Name of setting to get value for.  If empty, all settings are enumerated
#		[string]$strComputer: Array of strings of computer names to get the setting values for
# =============================================================================
#  Purpose:    Provides values for setting requested.      
#              
# =============================================================================
Function EnumSetting {

Param ([string]$strSetting = "", [array]$arrComputer=@("."))

foreach ($strComputer in $arrComputer)
{
	"--------------------------------------------------------------------"
	"Computer Name: " + $strComputer
	"--------------------------------------------------------------------"
	if ($strSetting -eq ""){
	Get-WmiObject HP_BIOSSetting -Namespace "root\HP\InstrumentedBIOS" `
	-ComputerName $strComputer | Format-Table -AutoSize -Property Name, Value
	}
	else{
	Get-WmiObject HP_BIOSSetting -Namespace "root\HP\InstrumentedBIOS" `
	-ComputerName $strComputer | Where-Object{$_.Name -eq $strSetting} | Format-Table -AutoSize -Property Name, Value
	}
}
}
#*=============================================================================
#* SCRIPT BODY
#*=============================================================================
#Write version string
$ScriptName + " Version " + $Version + "`n" + $Copyright + "`n"

# Parse command line arguments
[bool]$run = $true
[array]$arrComputer = @(".")
foreach ($i in $args) {
	if(($i -eq "/?") -or ($i -eq "-?")) {
		"============================================="
		"Usage:`nEnumSettings.ps1 /setting:""<setting name>"" <.> <computer1> <computer2>"
		"EnumSettings.ps1 <.> <computer1> <computer2>"
		"where <setting name>: A specific setting to get.  If a particular setting contains spaces, be sure to enclose the entire argument in quotation marks. If no setting is provided all settings are enumerated."
		"<.> <computer1> ...: An optional list of computers to query specified by name or IP address, otherwise the local system is used.  The dot nomenclature can also be used to include the local computer in the computer list."
		"Example1:`nEnumSettings.ps1 /setting:""Product Name"" . remote1 `n(will get 'Product Name' setting on current computer and remote1 computer)."
		"Example2:`nEnumSettings.ps1 `n(will get all settings on current computer)."
		"============================================="
		$run = $false
	}
	elseif($i.StartsWith("/setting"))
	{
		# get setting name if provided
		$strSetting = $i.Replace("/setting:", "")
	}
	else
	{
		# collect computer names
		if($i -ne "."){$arrComputer += $i}
	}
}
if ($run)
{
if($arrComputer.Count -eq 0){
	$arrComputer = @(".")
}

# Call the "EnumSetting" function.
EnumSetting $strSetting $arrComputer
}
#*=============================================================================
#* END OF SCRIPT
#*=============================================================================





# SIG # Begin signature block
# MIIWJgYJKoZIhvcNAQcCoIIWFzCCFhMCAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQUcn9Qh75ys6aM+w7mgB6GUmdh
# hKCgghGqMIIDejCCAmKgAwIBAgIQOCXX+vhhr570kOcmtdZa1TANBgkqhkiG9w0B
# AQUFADBTMQswCQYDVQQGEwJVUzEXMBUGA1UEChMOVmVyaVNpZ24sIEluYy4xKzAp
# BgNVBAMTIlZlcmlTaWduIFRpbWUgU3RhbXBpbmcgU2VydmljZXMgQ0EwHhcNMDcw
# NjE1MDAwMDAwWhcNMTIwNjE0MjM1OTU5WjBcMQswCQYDVQQGEwJVUzEXMBUGA1UE
# ChMOVmVyaVNpZ24sIEluYy4xNDAyBgNVBAMTK1ZlcmlTaWduIFRpbWUgU3RhbXBp
# bmcgU2VydmljZXMgU2lnbmVyIC0gRzIwgZ8wDQYJKoZIhvcNAQEBBQADgY0AMIGJ
# AoGBAMS18lIVvIiGYCkWSlsvS5Frh5HzNVRYNerRNl5iTVJRNHHCe2YdicjdKsRq
# CvY32Zh0kfaSrrC1dpbxqUpjRUcuawuSTksrjO5YSovUB+QaLPiCqljZzULzLcB1
# 3o2rx44dmmxMCJUe3tvvZ+FywknCnmA84eK+FqNjeGkUe60tAgMBAAGjgcQwgcEw
# NAYIKwYBBQUHAQEEKDAmMCQGCCsGAQUFBzABhhhodHRwOi8vb2NzcC52ZXJpc2ln
# bi5jb20wDAYDVR0TAQH/BAIwADAzBgNVHR8ELDAqMCigJqAkhiJodHRwOi8vY3Js
# LnZlcmlzaWduLmNvbS90c3MtY2EuY3JsMBYGA1UdJQEB/wQMMAoGCCsGAQUFBwMI
# MA4GA1UdDwEB/wQEAwIGwDAeBgNVHREEFzAVpBMwETEPMA0GA1UEAxMGVFNBMS0y
# MA0GCSqGSIb3DQEBBQUAA4IBAQBQxUvIJIDf5A0kwt4asaECoaaCLQyDFYE3CoIO
# LLBaF2G12AX+iNvxkZGzVhpApuuSvjg5sHU2dDqYT+Q3upmJypVCHbC5x6CNV+D6
# 1WQEQjVOAdEzohfITaonx/LhhkwCOE2DeMb8U+Dr4AaH3aSWnl4MmOKlvr+ChcNg
# 4d+tKNjHpUtk2scbW72sOQjVOCKhM4sviprrvAchP0RBCQe1ZRwkvEjTRIDroc/J
# ArQUz1THFqOAXPl5Pl1yfYgXnixDospTzn099io6uE+UAKVtCoNd+V5T9BizVw9w
# w/v1rZWgDhfexBaAYMkPK26GBPHr9Hgn0QXF7jRbXrlJMvIzMIIDxDCCAy2gAwIB
# AgIQR78Zld+NUkZD99ttSA0xpDANBgkqhkiG9w0BAQUFADCBizELMAkGA1UEBhMC
# WkExFTATBgNVBAgTDFdlc3Rlcm4gQ2FwZTEUMBIGA1UEBxMLRHVyYmFudmlsbGUx
# DzANBgNVBAoTBlRoYXd0ZTEdMBsGA1UECxMUVGhhd3RlIENlcnRpZmljYXRpb24x
# HzAdBgNVBAMTFlRoYXd0ZSBUaW1lc3RhbXBpbmcgQ0EwHhcNMDMxMjA0MDAwMDAw
# WhcNMTMxMjAzMjM1OTU5WjBTMQswCQYDVQQGEwJVUzEXMBUGA1UEChMOVmVyaVNp
# Z24sIEluYy4xKzApBgNVBAMTIlZlcmlTaWduIFRpbWUgU3RhbXBpbmcgU2Vydmlj
# ZXMgQ0EwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCpyrKkzM0grwp9
# iayHdfC0TvHfwQ+/Z2G9o2Qc2rv5yjOrhDCJWH6M22vdNp4Pv9HsePJ3pn5vPL+T
# rw26aPRslMq9Ui2rSD31ttVdXxsCn/ovax6k96OaphrIAuF/TFLjDmDsQBx+uQ3e
# P8e034e9X3pqMS4DmYETqEcgzjFzDVctzXg0M5USmRK53mgvqubjwoqMKsOLIYdm
# vYNYV291vzyqJoddyhAVPJ+E6lTBCm7E/sVK3bkHEZcifNs+J9EeeOyfMcnx5iIZ
# 28SzR0OaGl+gHpDkXvXufPF9q2IBj/VNC97QIlaolc2uiHau7roN8+RN2aD7aKCu
# FDuzh8G7AgMBAAGjgdswgdgwNAYIKwYBBQUHAQEEKDAmMCQGCCsGAQUFBzABhhho
# dHRwOi8vb2NzcC52ZXJpc2lnbi5jb20wEgYDVR0TAQH/BAgwBgEB/wIBADBBBgNV
# HR8EOjA4MDagNKAyhjBodHRwOi8vY3JsLnZlcmlzaWduLmNvbS9UaGF3dGVUaW1l
# c3RhbXBpbmdDQS5jcmwwEwYDVR0lBAwwCgYIKwYBBQUHAwgwDgYDVR0PAQH/BAQD
# AgEGMCQGA1UdEQQdMBukGTAXMRUwEwYDVQQDEwxUU0EyMDQ4LTEtNTMwDQYJKoZI
# hvcNAQEFBQADgYEASmv56ljCRBwxiXmZK5a/gqwB1hxMzbCKWG7fCCmjXsjKkxPn
# BFIN70cnLwA4sOTJk06a1CJiFfc/NyFPcDGA8Ys4h7Po6JcA/s9Vlk4k0qknTnqu
# t2FB8yrO58nZXt27K4U+tZ212eFX/760xX71zwye8Jf+K9M7UhsbOCf3P0owggS/
# MIIEKKADAgECAhBBkaFaOXjfz0llZjgdTHXCMA0GCSqGSIb3DQEBBQUAMF8xCzAJ
# BgNVBAYTAlVTMRcwFQYDVQQKEw5WZXJpU2lnbiwgSW5jLjE3MDUGA1UECxMuQ2xh
# c3MgMyBQdWJsaWMgUHJpbWFyeSBDZXJ0aWZpY2F0aW9uIEF1dGhvcml0eTAeFw0w
# NDA3MTYwMDAwMDBaFw0xNDA3MTUyMzU5NTlaMIG0MQswCQYDVQQGEwJVUzEXMBUG
# A1UEChMOVmVyaVNpZ24sIEluYy4xHzAdBgNVBAsTFlZlcmlTaWduIFRydXN0IE5l
# dHdvcmsxOzA5BgNVBAsTMlRlcm1zIG9mIHVzZSBhdCBodHRwczovL3d3dy52ZXJp
# c2lnbi5jb20vcnBhIChjKTA0MS4wLAYDVQQDEyVWZXJpU2lnbiBDbGFzcyAzIENv
# ZGUgU2lnbmluZyAyMDA0IENBMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC
# AQEAvrzuvH7vg+vgN0/7AxA4vgjSjH2d+pJ/GQzCa+5CUoze0xxIEyXqwWN6+VFl
# 7tOqO/XwlJwr+/Jm1CTa9/Wfbhk5NrzQo3YIHiInJGw4kSfihEmuG4qh/SWCLBAw
# 6HGrKOh3SlHx7M348FTUb8DjbQqP2dhkjWOyLU4n9oUO/m3jKZnihUd8LYZ/6FeP
# rWfCMzKREyD8qSMUmm3ChEt2aATVcSxdIfqIDSb9Hy2RK+cBVU3ybTUogt/Za1y2
# 1tmqgf1fzYO6Y53QIvypO0Jpso46tby0ng9exOosgoso/VMIlt21ASDR+aUY58Du
# UXA34bYFSFJIbzjqw+hse0SEuwIDAQABo4IBoDCCAZwwEgYDVR0TAQH/BAgwBgEB
# /wIBADBEBgNVHSAEPTA7MDkGC2CGSAGG+EUBBxcDMCowKAYIKwYBBQUHAgEWHGh0
# dHBzOi8vd3d3LnZlcmlzaWduLmNvbS9ycGEwMQYDVR0fBCowKDAmoCSgIoYgaHR0
# cDovL2NybC52ZXJpc2lnbi5jb20vcGNhMy5jcmwwHQYDVR0lBBYwFAYIKwYBBQUH
# AwIGCCsGAQUFBwMDMA4GA1UdDwEB/wQEAwIBBjARBglghkgBhvhCAQEEBAMCAAEw
# KQYDVR0RBCIwIKQeMBwxGjAYBgNVBAMTEUNsYXNzM0NBMjA0OC0xLTQzMB0GA1Ud
# DgQWBBQI9VHo+/49PWQ2fGjPW3io37nFNzCBgAYDVR0jBHkwd6FjpGEwXzELMAkG
# A1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJbmMuMTcwNQYDVQQLEy5DbGFz
# cyAzIFB1YmxpYyBQcmltYXJ5IENlcnRpZmljYXRpb24gQXV0aG9yaXR5ghBwuuQd
# ENkpNLY4ynsDzLq/MA0GCSqGSIb3DQEBBQUAA4GBAK46F7hKe1X6ZFXsQKTtSUGQ
# mZyJvK8uHcp4I/kcGQ9/62i8MtmION7cP9OJtD+xgpbxpFq67S4m0958AW4ACgCk
# BpIRSAlA+RwYeWcjJOC71eFQrhv1Dt3gLoHNgKNsUk+RdVWKuiLy0upBdYgvY1V9
# HlRalVnK2TSBwF9e9nq1MIIFnTCCBIWgAwIBAgIQCJlFMf3xsuu4x4Ib9lD9zzAN
# BgkqhkiG9w0BAQUFADCBtDELMAkGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWdu
# LCBJbmMuMR8wHQYDVQQLExZWZXJpU2lnbiBUcnVzdCBOZXR3b3JrMTswOQYDVQQL
# EzJUZXJtcyBvZiB1c2UgYXQgaHR0cHM6Ly93d3cudmVyaXNpZ24uY29tL3JwYSAo
# YykwNDEuMCwGA1UEAxMlVmVyaVNpZ24gQ2xhc3MgMyBDb2RlIFNpZ25pbmcgMjAw
# NCBDQTAeFw0wODEyMTgwMDAwMDBaFw0xMTEyMTgyMzU5NTlaMIHcMQswCQYDVQQG
# EwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTESMBAGA1UEBxMJUGFsbyBBbHRvMSAw
# HgYDVQQKFBdIZXdsZXR0LVBhY2thcmQgQ29tcGFueTE+MDwGA1UECxM1RGlnaXRh
# bCBJRCBDbGFzcyAzIC0gTWljcm9zb2Z0IFNvZnR3YXJlIFZhbGlkYXRpb24gdjIx
# IDAeBgNVBAsUF0hld2xldHQtUGFja2FyZCBDb21wYW55MSAwHgYDVQQDFBdIZXds
# ZXR0LVBhY2thcmQgQ29tcGFueTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC
# ggEBALydQVhXR+j196HFpbtD3cnX0SXBJUO0ayNWcm20ww2PIgyY4BnIk+hz6hug
# enjq2U3tGSykdhSfEIfADwAznYTHmtmotb2nR1EkHdON+wkrRH+lPeP6g8uIY1BI
# vVgzMQMkpGcFyt8mvR0t7xS/00lwk8HZctVcjXk1ncmr+yR5OWnoA+IwVB7YphCV
# t2bEKnaMxDBj8QWXRpf5qWbgZjgkLlOnENGDgusItfvYpSzroM3ayESROJegPIDv
# /UhJUFLvGN+RaoA2stAatL1279PuTvh1SreI9CCxrspDTzr9NcchOmKrB8X0FOZz
# gHjn/ya2zpUQ4usNp5fSVRjmPBMCAwEAAaOCAX8wggF7MAkGA1UdEwQCMAAwDgYD
# VR0PAQH/BAQDAgeAMEAGA1UdHwQ5MDcwNaAzoDGGL2h0dHA6Ly9DU0MzLTIwMDQt
# Y3JsLnZlcmlzaWduLmNvbS9DU0MzLTIwMDQuY3JsMEQGA1UdIAQ9MDswOQYLYIZI
# AYb4RQEHFwMwKjAoBggrBgEFBQcCARYcaHR0cHM6Ly93d3cudmVyaXNpZ24uY29t
# L3JwYTATBgNVHSUEDDAKBggrBgEFBQcDAzB1BggrBgEFBQcBAQRpMGcwJAYIKwYB
# BQUHMAGGGGh0dHA6Ly9vY3NwLnZlcmlzaWduLmNvbTA/BggrBgEFBQcwAoYzaHR0
# cDovL0NTQzMtMjAwNC1haWEudmVyaXNpZ24uY29tL0NTQzMtMjAwNC1haWEuY2Vy
# MB8GA1UdIwQYMBaAFAj1Uej7/j09ZDZ8aM9beKjfucU3MBEGCWCGSAGG+EIBAQQE
# AwIEEDAWBgorBgEEAYI3AgEbBAgwBgEBAAEB/zANBgkqhkiG9w0BAQUFAAOCAQEA
# kXBGP2UhVPzkpr20FxLPXGoYy3OonVMZGh8TMguzYpMC/CcFvz8v0V7t90FnRSCE
# pMsyoAgLzjj3vE15zxOC5BXn65GsYVz2Yk3kQyD4Q42tM0KxuTg3Vtf1c7tdtRIY
# DT19KznHuUKUCmGsb41g2hF0Y3C8qahK0KX0zn6sb+Vs4Qds2zB5sIroG6KcfXin
# vJ7yWtQQY/v14vVaG0j3C0lnwIa03b9tqkPMy9DaeQnSWztinosoKipw+nKbFlMl
# gHghPHnSFfn0lHK67icWxqaUiEUylY6AQK8nSAArff1+JHLMlHkghKj+igtWLM2F
# 69ZIVEM6/JtuPpIICI6qqTGCA+YwggPiAgEBMIHJMIG0MQswCQYDVQQGEwJVUzEX
# MBUGA1UEChMOVmVyaVNpZ24sIEluYy4xHzAdBgNVBAsTFlZlcmlTaWduIFRydXN0
# IE5ldHdvcmsxOzA5BgNVBAsTMlRlcm1zIG9mIHVzZSBhdCBodHRwczovL3d3dy52
# ZXJpc2lnbi5jb20vcnBhIChjKTA0MS4wLAYDVQQDEyVWZXJpU2lnbiBDbGFzcyAz
# IENvZGUgU2lnbmluZyAyMDA0IENBAhAImUUx/fGy67jHghv2UP3PMAkGBSsOAwIa
# BQCgcDAQBgorBgEEAYI3AgEMMQIwADAZBgkqhkiG9w0BCQMxDAYKKwYBBAGCNwIB
# BDAcBgorBgEEAYI3AgELMQ4wDAYKKwYBBAGCNwIBFTAjBgkqhkiG9w0BCQQxFgQU
# CPGa+wkOejrllxXEwfH54TJqdsAwDQYJKoZIhvcNAQEBBQAEggEAh/IzZQaXANjI
# CunV9lO2bCw7ZGryYdZEV5/PQbLPjFk0LakBHNblMwRNjO5Ejoy+9PP/SbrfDXyw
# Gyr4OWUtcNK7ewnUm4c+Ng85RnWXXZMjO+iSwKSQmJYnKIKJ1QCe/37Emx8u6hLv
# JdBIKbIAQykoDu4PyI/wi5vrVdkPoWABi5CdXrp8U1g9pXFeAoY9Uf7nOZgacaDg
# v7OpHXMy4hjwyb5KW94Sbs1UtcTttZGXKF98vEGCTIinLBYZAggeDMvPuIewTd+l
# GAoukveJz/5wlhcIM9Fi0HiUzNYVSzIkVIpYw9aAOaAjaHO3Rztu2iVIYK9Mun0A
# R6jwRdMAVaGCAX8wggF7BgkqhkiG9w0BCQYxggFsMIIBaAIBATBnMFMxCzAJBgNV
# BAYTAlVTMRcwFQYDVQQKEw5WZXJpU2lnbiwgSW5jLjErMCkGA1UEAxMiVmVyaVNp
# Z24gVGltZSBTdGFtcGluZyBTZXJ2aWNlcyBDQQIQOCXX+vhhr570kOcmtdZa1TAJ
# BgUrDgMCGgUAoF0wGAYJKoZIhvcNAQkDMQsGCSqGSIb3DQEHATAcBgkqhkiG9w0B
# CQUxDxcNMDkwNDIyMjIxNDI1WjAjBgkqhkiG9w0BCQQxFgQUSGo5YD/f5uvGX2sz
# E7s6ProUkDEwDQYJKoZIhvcNAQEBBQAEgYBY13o1ZlvbjEyEi06UpvEgosDLwH6Z
# BYGIYjZEr4tgKsm1q5feTquBhaGPO3oUvQHxliMmFlu9954qJxwdiuyIXvbx7rGz
# VgSM6EyePumvFygbzDtWdtmIFfZIHueBdQtgwGo9K01w9ecqN2CsOE+3GVRb22Zd
# PTTNqoitPZZEtQ==
# SIG # End signature block
